pub struct MlmeReadApfPacketFilterDataResponse {
pub memory: Vec<u8>,
}Fields
memory: Vec<u8>Trait Implementations
Sourceimpl Clone for MlmeReadApfPacketFilterDataResponse
impl Clone for MlmeReadApfPacketFilterDataResponse
Sourcefn clone(&self) -> MlmeReadApfPacketFilterDataResponse
fn clone(&self) -> MlmeReadApfPacketFilterDataResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<MlmeReadApfPacketFilterDataResponse, D> for MlmeReadApfPacketFilterDataResponse
impl<D: ResourceDialect> Decode<MlmeReadApfPacketFilterDataResponse, D> for MlmeReadApfPacketFilterDataResponse
Sourceimpl<D: ResourceDialect> Encode<MlmeReadApfPacketFilterDataResponse, D> for &MlmeReadApfPacketFilterDataResponse
impl<D: ResourceDialect> Encode<MlmeReadApfPacketFilterDataResponse, D> for &MlmeReadApfPacketFilterDataResponse
Sourceimpl<D: ResourceDialect, T0: Encode<UnboundedVector<u8>, D>> Encode<MlmeReadApfPacketFilterDataResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<UnboundedVector<u8>, D>> Encode<MlmeReadApfPacketFilterDataResponse, D> for (T0,)
Sourceimpl Ord for MlmeReadApfPacketFilterDataResponse
impl Ord for MlmeReadApfPacketFilterDataResponse
Sourcefn cmp(&self, other: &MlmeReadApfPacketFilterDataResponse) -> Ordering
fn cmp(&self, other: &MlmeReadApfPacketFilterDataResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MlmeReadApfPacketFilterDataResponse
impl PartialEq for MlmeReadApfPacketFilterDataResponse
Sourcefn eq(&self, other: &MlmeReadApfPacketFilterDataResponse) -> bool
fn eq(&self, other: &MlmeReadApfPacketFilterDataResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MlmeReadApfPacketFilterDataResponse
impl PartialOrd for MlmeReadApfPacketFilterDataResponse
Sourceimpl TypeMarker for MlmeReadApfPacketFilterDataResponse
impl TypeMarker for MlmeReadApfPacketFilterDataResponse
Sourcetype Owned = MlmeReadApfPacketFilterDataResponse
type Owned = MlmeReadApfPacketFilterDataResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for MlmeReadApfPacketFilterDataResponse
impl ValueTypeMarker for MlmeReadApfPacketFilterDataResponse
Sourcetype Borrowed<'a> = &'a MlmeReadApfPacketFilterDataResponse
type Borrowed<'a> = &'a MlmeReadApfPacketFilterDataResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Eq for MlmeReadApfPacketFilterDataResponse
impl Persistable for MlmeReadApfPacketFilterDataResponse
impl StructuralPartialEq for MlmeReadApfPacketFilterDataResponse